#! /usr/bin/env python
#
# Copyright David Faure <faure@kde.org>, License LGPL v2
#
# This script converts a kde3 screensaver to kde4, adapting it to the change
# of API in libkscreensaver.
#
# If the input file could be parsed correctly (i.e. it had extern "C" and kss_* symbols),
# then this script will *overwrite* it with the result of the conversion.
# Make backups first, if you don't use a version control system.
#
# Usage: change those two lines before running the script
#
filename = 'pendulum.cpp'
savername = 'KPendulumSaver'   # Interface is appended to this string.

import string,re,os
f = file(filename, 'r')
data = f.read()
lines = data.split('\n')
externCRe = re.compile('^\s*extern "C"')
appNameRe = re.compile('.*kss_applicationName\s*=\s*(".*")')
descriptionRe = re.compile('.*kss_description\s*=\s*(.*);')
versionRe = re.compile('.*kss_version\s*=\s*(.*);')
inExternC = 0
braceLevel = 0
aboutDataWritten = 0
appName = ''
description = ''
version = ''
outputlines = []
for line in lines:
	if (line[0:2] == '//'):
		outputlines.append(line)
		continue
	if not inExternC:
		if (externCRe.match(line)):
			inExternC = 1
			if (line.find('{') >= 0):
				braceLevel = braceLevel+1
	   		outputlines.append(line.replace('extern "C"', 'class ' + savername + 'Interface : public KScreenSaverInterface'))
		else:
			outputlines.append(line)
	else:
		if (line.find('{') >= 0):
			braceLevel = braceLevel+1
		if (line.find('}') >= 0):
	   		braceLevel = braceLevel-1
		match = appNameRe.match(line)
		if match:
			appName = match.group(1)
			line = ''
		match = descriptionRe.match(line)
		if match:
			description = match.group(1)
			line = ''
		match = versionRe.match(line)
		if match:
			version = match.group(1)
			line = ''
		if appName and description and version and not aboutDataWritten:
			outputlines.append( "public:" )
			outputlines.append( "    virtual KAboutData* aboutData() {" )
			outputlines.append( "        return new KAboutData( " + appName + ", " + description + ", " + version + ", " + description + " );" )
			outputlines.append( "    }" )
			aboutDataWritten = 1

		line = re.sub('KDE_EXPORT\s*','',line)
		line = re.sub('KScreenSaver\s*\*\s*kss_create','virtual KScreenSaver* create',line)
		line = re.sub('QDialog\s*\*\s*kss_setup','virtual QDialog* setup',line)
		if braceLevel == 0:
			outputlines.append( '};' )
			outputlines.append( '' )
			outputlines.append( 'int main( int argc, char *argv[] )' )
			outputlines.append( '{' )
			outputlines.append( '    ' + savername + 'Interface kss;' )
			outputlines.append( '    return kScreenSaverMain( argc, argv, kss );' )
			outputlines.append( '}' )
			inExternC = 0
		else:
			outputlines.append( line )

if not aboutDataWritten:
	print "PARSE ERROR"
	print 'appName=' + appName
	print 'description=' + description
	print 'version=' + version
else:
	open(filename,"w").write(string.join(outputlines, '\n'))
	os.system('svn di ' + filename)



# -*- coding: utf-8 -*-
#
# Copyright 2008 Simon Edwards <simon@simonzone.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU Library General Public License as
# published by the Free Software Foundation; either version 2, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details
#
# You should have received a copy of the GNU Library General Public
# License along with this program; if not, write to the
# Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#

# Plasma applet API for Python

from PyQt4.QtCore import QObject
from PyQt4.QtGui import QGraphicsWidget
from PyKDE4.plasma import Plasma # Plasma C++ namespace

#import sip
#import gc

class Applet(QObject):
    ''' Subclass Applet in your module and return an instance of it in a global function named
    applet(). Implement the following functions to breathe life into your applet:
        * paint - Draw the applet given a QPainter and some options
    It provides the same API as Plasma.Applet; it just has slightly less irritating event names. '''
    def __init__(self, parent=None):
        # this should be set when the applet is created
        QObject.__init__(self, parent)
        #sip.settracemask(0x3f)
        self.applet = None
        self.applet_script = None
        self._forward_to_applet = True

    def __getattr__(self, key):
        # provide transparent access to the real applet instance
        if self._forward_to_applet:
            try:
                return getattr(self.applet_script, key)
            except:
                return getattr(self.applet, key)
        else:
            raise AttributeError(key)

    def _enableForwardToApplet(self):
        self._forward_to_applet = True
    def _disableForwardToApplet(self):
        self._forward_to_applet = False

    # Events
    def setApplet(self,applet):
        self.applet = applet

    def setAppletScript(self,appletScript):
        self.applet_script = appletScript

    def init(self):
        pass

    def configChanged(self):
        pass

    def paintInterface(self, painter, options, rect):
        pass

    def constraintsEvent(self, flags):
        pass

    def showConfigurationInterface(self):
        self.dlg = self.standardConfigurationDialog()
        self.createConfigurationInterface(self.dlg)
        self.addStandardConfigurationPages(self.dlg)
        self.dlg.show()

    def createConfigurationInterface(self, dlg):
        pass

    def contextualActions(self):
        return []

    def shape(self):
        return QGraphicsWidget.shape(self.applet)

    def initExtenderItem(self, item):
        print ("Missing implementation of initExtenderItem in the applet " + \
              item.config().readEntry('SourceAppletPluginName', '').toString() + \
              "!\nAny applet that uses extenders should implement initExtenderItem to " + \
              "instantiate a widget.")

    def saveState(self, config):
        pass

###########################################################################
class DataEngine(QObject):
    def __init__(self, parent=None):
        QObject.__init__(self, parent)
        self.dataengine = None
        self.dataengine_script = None

    def setDataEngine(self,dataEngine):
        self.dataEngine = dataEngine

    def setDataEngineScript(self,dataEngineScript):
        self.data_engine_script = dataEngineScript

    def __getattr__(self, key):
        # provide transparent access to the real dataengine script instance
        try:
            return getattr(self.data_engine_script, key)
        except:
            return getattr(self.dataEngine, key)

    def init(self):
        pass

    def sources(self):
        return []

    def sourceRequestEvent(self,name):
        return False

    def updateSourceEvent(self,source):
        return False

    def serviceForSource(self,source):
        return Plasma.DataEngineScript.serviceForSource(self.data_engine_script,source)

###########################################################################
class Wallpaper(QObject):
    def __init__(self, parent=None):
        QObject.__init__(self, parent)
        self.wallpaper = None
        self.wallpaper_script = None

    def setWallpaper(self,wallpaper):
        self.wallpaper = wallpaper

    def setWallpaperScript(self,wallpaperScript):
        self.wallpaper_script = wallpaperScript

    def __getattr__(self, key):
        # provide transparent access to the real wallpaper script instance
        try:
            return getattr(self.wallpaper_script, key)
        except:
            return getattr(self.wallpaper, key)

    def init(self, config):
        pass

    def paint(self,painter, exposedRect):
        pass

    def save(self,config):
        pass

    def createConfigurationInterface(self,parent):
        return None

    def mouseMoveEvent(self,event):
        pass

    def mousePressEvent(self,event):
        pass

    def mouseReleaseEvent(self,event):
        pass

    def wheelEvent(self,event):
        pass

    def renderCompleted(self, image):
        pass

    def urlDropped(self, url):
        pass

###########################################################################
class Runner(QObject):
    def __init__(self, parent=None):
        QObject.__init__(self, parent)
        self.runner = None
        self.runner_script = None

    def setRunner(self,runner):
        self.runner = runner

    def setRunnerScript(self,runnerScript):
        self.runner_script = runnerScript

    def __getattr__(self, key):
        # provide transparent access to the real runner script instance
        try:
            return getattr(self.runner_script, key)
        except:
            return getattr(self.runner, key)

    def init(self):
        pass

    def match(self, search):
        pass

    def run(self, search, action):
        pass

    def prepare(self):
        pass

    def teardown(self):
        pass

    def createRunOptions(self, widget):
        pass

    def reloadConfiguration(self):
        pass



# -*- coding: utf-8 -*-
#
# Copyright 2008 Simon Edwards <simon@simonzone.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU Library General Public License as
# published by the Free Software Foundation; either version 2, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details
#
# You should have received a copy of the GNU Library General Public
# License along with this program; if not, write to the
# Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
from PyQt4.QtCore import *
from PyQt4.QtGui import *
from PyKDE4.plasma import Plasma
import plasma_importer
import os.path

class PythonAppletScript(Plasma.AppletScript):
    importer = None

    def __init__(self, parent):
        Plasma.AppletScript.__init__(self,parent)
        #print("PythonAppletScript()")
        if PythonAppletScript.importer is None:
             PythonAppletScript.importer = plasma_importer.PlasmaImporter()
        self.initialized = False

    def init(self):
        #print("Script Name: " + str(self.applet().name()))
        #print("Script Category: " + str(self.applet().category()))

        # applet() cannot be relied on to give the right details in the destructor,
        # so the plugin name is stored aside. (n.b module.__name__ cannot be relied
        # on either; it might have been changed in the module itself)
        self.moduleName = str(self.applet().pluginName())
        #print("pluginname: " + str(self.applet().pluginName()))
        self.pluginName = 'applet_' + self.moduleName.replace('-','_')

        PythonAppletScript.importer.register_top_level(self.pluginName, str(self.applet().package().path()))

        #print("mainScript: " + str(self.mainScript()))
        #print("package path: " + str(self.applet().package().path()))

        # import the code at the file name reported by mainScript()
        relpath = os.path.relpath(str(self.mainScript()),str(self.applet().package().path()))
        if relpath.startswith("contents/code/"):
            relpath = relpath[14:]
        if relpath.endswith(".py"):
            relpath = relpath[:-3]
        relpath = relpath.replace("/",".")
        self.module = __import__(self.pluginName+'.'+relpath)

        # Plasma main scripts not necessarily are named "main"
        # So we use __dict__ to get the right main script name
        basename = os.path.basename(str(self.mainScript()))
        basename = os.path.splitext(basename)[0]
        self.pyapplet = self.module.__dict__[basename].CreateApplet(None)
        self.pyapplet.setApplet(self.applet())
        self.pyapplet.setAppletScript(self)
        self.connect(self.applet(), SIGNAL('extenderItemRestored(Plasma::ExtenderItem*)'),
                     self, SLOT('initExtenderItem(Plasma::ExtenderItem*)'))
        self.connect(self, SIGNAL('saveState(KConfigGroup&)'),
                     self, SLOT('saveStateSlot(KConfigGroup&)'))
        self._setUpEventHandlers()
        self.initialized = True

        self.pyapplet.init()
        return True

    def __dtor__(self):
        #print("~PythonAppletScript()")
        if not self.initialized:
            return

        PythonAppletScript.importer.unregister_top_level(self.pluginName)
        self.pyapplet = None

    @pyqtSignature("initExtenderItem(Plasma::ExtenderItem*)")
    def initExtenderItem(self, item):
        if not self.initialized:
            return
        self.pyapplet.initExtenderItem(item)

    @pyqtSignature("saveStateSlot(KConfigGroup&)")
    def saveStateSlot(self, config):
        if not self.initialized:
            return
        self.pyapplet.saveState(config)

    def constraintsEvent(self, constraints):
        if not self.initialized:
            return
        self.pyapplet.constraintsEvent(constraints)

    def showConfigurationInterface(self):
        if not self.initialized:
            return
        #print("Script: showConfigurationInterface")
        self.pyapplet.showConfigurationInterface()

    def configChanged(self):
        if not self.initialized:
            return
        self.pyapplet.configChanged()

    def paintInterface(self, painter, option, contentsRect):
        if not self.initialized:
            return
        self.pyapplet.paintInterface(painter, option, contentsRect)

    def contextualActions(self):
        if not self.initialized:
            return

        #print("pythonapplet contextualActions()")
        return self.pyapplet.contextualActions()

    def shape(self):
        if not self.initialized:
            return QPainterPath()
        return self.pyapplet.shape()

    def eventFilter(self, obj, event):
        handler = self.event_handlers.get(event.type(),None)
        if handler is not None:
            apply(getattr(self.pyapplet,handler), (event,) )
            return True
        else:
            return False

    def _setUpEventHandlers(self):
        self.event_handlers = {}

        self.pyapplet._disableForwardToApplet()
        for event_type,handler in {
            QEvent.GraphicsSceneMousePress: "mousePressEvent",
            QEvent.GraphicsSceneContextMenu: "contextMenuEvent",
            QEvent.GraphicsSceneDragEnter: "dragEnterEvent",
            QEvent.GraphicsSceneDragLeave: "dragLeaveEvent",
            QEvent.GraphicsSceneDragMove: "dragMoveEvent",
            QEvent.GraphicsSceneDrop: "dropEvent",
            QEvent.FocusIn: "focusInEvent",
            QEvent.FocusOut: "focusOutEvent",
            QEvent.GraphicsSceneHoverEnter: "hoverEnterEvent",
            QEvent.GraphicsSceneHoverLeave: "hoverLeaveEvent",
            QEvent.GraphicsSceneHoverMove: "hoverMoveEvent",
            QEvent.InputMethod: "inputMethodEvent",
            QEvent.KeyPress: "keyPressEvent",
            QEvent.KeyRelease: "keyReleaseEvent",
            QEvent.GraphicsSceneMouseDoubleClick: "mouseDoubleClickEvent",
            QEvent.GraphicsSceneMouseMove: "mouseMoveEvent",
            QEvent.GraphicsSceneMousePress: "mousePressEvent",
            QEvent.GraphicsSceneMouseRelease: "mouseReleaseEvent",
            QEvent.GraphicsSceneWheel: "wheelEvent"
        }.iteritems():
            if hasattr(self.pyapplet,handler):
                self.event_handlers[event_type] = handler
        self.pyapplet._enableForwardToApplet()

        if self.event_handlers:
            self.applet().installEventFilter(self)

def CreatePlugin(widget_parent, parent, component_data):
    return PythonAppletScript(parent)



# -*- coding: utf-8 -*-
#
# Copyright 2008 Simon Edwards <simon@simonzone.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU Library General Public License as
# published by the Free Software Foundation; either version 2, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details
#
# You should have received a copy of the GNU Library General Public
# License along with this program; if not, write to the
# Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#

import sys
import os
import imp

PY3 = sys.version_info[0] == 3


class PlasmaImporter(object):
    def __init__(self):
        self.toplevel = {}
        self.toplevelcount = {}
        self.marker = '<plasma>' + str(id(self))
        sys.path.append(self.marker)
        sys.path_hooks.append(self.hook)

    def hook(self,path):
      if path==self.marker:
          return self
      else:
          raise ImportError()

    def register_top_level(self,name,path):
        if name not in self.toplevel:
            self.toplevelcount[name] = 1
            self.toplevel[name] = path
        else:
            self.toplevelcount[name] += 1

    def unregister_top_level(self,name):
        value = self.toplevelcount[name]-1
        self.toplevelcount[name] = value
        if value==0:
            del self.toplevelcount[name]
            del self.toplevel[name]
            for key in list(sys.modules.keys()):
                if key==name or key.startswith(name+"."):
                    del sys.modules[key]

    def find_module(self,fullname, path=None):
        location = self.find_pymod(fullname)
        if location is not None:
            return self
        else:
            return None

    # Find the given module in the plasma directory.
    # Result a tuple on success otherwise None. The tuple contains the location
    # of the module/package in disk and a boolean indicating if it is a package
    # or module
    def find_pymod(self,modulename):
        parts = modulename.split('.')
        toppackage = parts[0]
        rest = parts[1:]

        if toppackage in self.toplevel:
            path = self.toplevel[toppackage]
            if len(rest)==0:
                # Simple top level Plasma package
                return (path,True)
            else:
                restpath = apply(os.path.join,rest)
                fullpath = os.path.join(path,'contents','code',restpath)
                if os.path.isdir(fullpath):
                    return (fullpath,True)
                elif os.path.exists(fullpath+'.py'):
                    return (fullpath+'.py',False)
        else:
            return None

    def _get_code(self,location):
        return open(location).read()

    def load_module(self, fullname):
        location,ispkg = self.find_pymod(fullname)
        if ispkg:   # Package dir.
            initlocation = os.path.join(location,'__init__.py')
            code = None
            if os.path.isfile(initlocation):
                code = open(initlocation)
        else:
            code = open(location)

        mod = sys.modules.setdefault(fullname, imp.new_module(fullname))
        mod.__file__ = location #"<%s>" % self.__class__.__name__
        mod.__loader__ = self
        if ispkg:
            mod.__path__ = [self.marker]
        if code is not None:
            try:
                if PY3:
                    exec(code in mod.__dict__)
                else:
                    exec code in mod.__dict__
            finally:
                code.close()
        return mod

#plasma_importer = PlasmaImporter()
#plasma_importer.register_top_level('plasma_pyclock','/home/sbe/devel/python_plasma_2/test/plasma-pyclock')
#from  plasma_pyclock import main



# -*- coding: utf-8 -*-
#
# Copyright 2008 Simon Edwards <simon@simonzone.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU Library General Public License as
# published by the Free Software Foundation; either version 2, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details
#
# You should have received a copy of the GNU Library General Public
# License along with this program; if not, write to the
# Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
from PyQt4.QtCore import *
from PyQt4.QtGui import *
from PyKDE4.plasma import Plasma
import plasma_importer
import os.path

class PythonDataEngineScript(Plasma.DataEngineScript):
    importer = None

    def __init__(self, parent):
        Plasma.DataEngineScript.__init__(self,parent)
        if PythonDataEngineScript.importer is None:
            PythonDataEngineScript.importer = plasma_importer.PlasmaImporter()
        self.initialized = False

    def init(self):
        self.moduleName = str(self.dataEngine().pluginName())
        self.pluginName = 'dataengine_' + self.moduleName.replace('-','_')

        PythonDataEngineScript.importer.register_top_level(self.pluginName, str(self.dataEngine().package().path()))

        # import the code at the file name reported by mainScript()
        relpath = os.path.relpath(str(self.mainScript()),str(self.dataEngine().package().path()))
        if relpath.startswith("contents/code/"):
            relpath = relpath[14:]
        if relpath.endswith(".py"):
            relpath = relpath[:-3]
        relpath = relpath.replace("/",".")
        self.module = __import__(self.pluginName+'.'+relpath)
        # The script may not necessarily be called "main"
        # So we use __dict__ to look up the right name
        basename = os.path.basename(str(self.mainScript()))
        basename = os.path.splitext(basename)[0]

        self.pydataengine = self.module.__dict__[basename].CreateDataEngine(None)
        self.pydataengine.setDataEngine(self.dataEngine())
        self.pydataengine.setDataEngineScript(self)
        self.pydataengine.init()

        self.initialized = True
        return True

    def __dtor__(self):
        PythonDataEngineScript.importer.unregister_top_level(self.pluginName)
        self.pydataengine = None

    def sources(self):
        return self.pydataengine.sources()

    def serviceForSource(self,source):
        return self.pydataengine.serviceForSource(source)

    def sourceRequestEvent(self,name):
        return self.pydataengine.sourceRequestEvent(name)

    def updateSourceEvent(self,source):
        return self.pydataengine.updateSourceEvent(source)

def CreatePlugin(widget_parent, parent, component_data):
    return PythonDataEngineScript(parent)



# -*- coding: utf-8 -*-
#
# Copyright 2008 Simon Edwards <simon@simonzone.com>
# Copyright 2009 Petri Damstén <damu@iki.fi>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU Library General Public License as
# published by the Free Software Foundation; either version 2, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details
#
# You should have received a copy of the GNU Library General Public
# License along with this program; if not, write to the
# Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
from PyQt4.QtCore import *
from PyQt4.QtGui import *
from PyKDE4.plasma import Plasma
import plasma_importer
import os.path

class PythonWallpaperScript(Plasma.WallpaperScript):
    importer = None

    def __init__(self, parent):
        Plasma.WallpaperScript.__init__(self,parent)
        if PythonWallpaperScript.importer is None:
            PythonWallpaperScript.importer = plasma_importer.PlasmaImporter()
        self.initialized = False

    def init(self):
        self.moduleName = str(self.wallpaper().pluginName())
        self.pluginName = 'wallpaper_' + self.moduleName.replace('-','_')

        PythonWallpaperScript.importer.register_top_level(self.pluginName, str(self.wallpaper().package().path()))

        # import the code at the file name reported by mainScript()
        relpath = os.path.relpath(str(self.mainScript()),str(self.wallpaper().package().path()))
        if relpath.startswith("contents/code/"):
            relpath = relpath[14:]
        if relpath.endswith(".py"):
            relpath = relpath[:-3]
        relpath = relpath.replace("/",".")
        self.module = __import__(self.pluginName+'.'+relpath)
        self.pywallpaper = self.module.main.CreateWallpaper(None)
        self.pywallpaper.setWallpaper(self.wallpaper())
        self.pywallpaper.setWallpaperScript(self)
        self.initialized = True
        return True

    def __dtor__(self):
        PythonWallpaperScript.importer.unregister_top_level(self.pluginName)
        self.pywallpaper = None

    def paint(self, painter, exposedRect):
        self.pywallpaper.paint(painter, exposedRect)

    def initWallpaper(self, config):
        self.pywallpaper.init(config)

    def save(self, config):
        self.pywallpaper.save(config)

    def createConfigurationInterface(self, parent):
        self.connect(self, SIGNAL('settingsChanged(bool)'), parent, SLOT('settingsChanged(bool)'))
        return self.pywallpaper.createConfigurationInterface(parent)

    def settingsChanged(self, changed):
        self.emit(SIGNAL('settingsChanged(bool)'), changed)

    def mouseMoveEvent(self, event):
        self.pywallpaper.mouseMoveEvent(event)

    def mousePressEvent(self, event):
        self.pywallpaper.mousePressEvent(event)

    def mouseReleaseEvent(self, event):
        self.pywallpaper.mouseReleaseEvent(event)

    def wheelEvent(self, event):
        self.pywallpaper.wheelEvent(event)

    @pyqtSignature("renderCompleted(const QImage&)")
    def renderCompleted(self, image):
        self.pywallpaper.renderCompleted(image)

    @pyqtSignature("urlDropped(const KUrl&)")
    def urlDropped(self, url):
        self.pywallpaper.urlDropped(url)

def CreatePlugin(widget_parent, parent, component_data):
    return PythonWallpaperScript(parent)



#!/usr/bin/env python

#
# This python helper script does blend 2 images together and produces
# a by KSplashX usuable PNG animation file.
#
# Use:
# blend.py img1.png img2.png output.png
#

import sys, os, getopt, Image, ImageFile

def generate(srcfile1,srcfile2,destfile):
    srcimg1 = Image.open(srcfile1)
    srcimg2 = Image.open(srcfile2)

    (width1,height1) = srcimg1.size
    (width2,height2) = srcimg2.size

    maxwidth = width1>width2 and width1 or width2
    maxheight = height1>height2 and height1 or height2

    if width1 != maxwidth or height1 != maxheight:
        srcimg1.resize( (maxwidth,maxheight) )
    if width2 != maxwidth or height2 != maxheight:
        srcimg2.resize( (maxwidth,maxheight) )

    destimg = Image.new( "RGBA", (maxwidth*10,maxheight*2) )
    for row in range(1,3):
        for col in range(1,11):
            if row==1:
                alpha = col*row/10.0
            else:
                alpha = 1.0 - (col*row/20.0)
            img = Image.blend(srcimg1, srcimg2, alpha)
            x = maxwidth * col - maxwidth
            y = maxheight * row - maxheight
            destimg.paste(img,(x,y))
    destimg.save(destfile)

def main(argv):
    def usage():
        print "Syntax: %s <inputimagefile1> <inputimagefile2> <outputimagefile>" % os.path.basename(argv[0])

    try:
        opts, args = getopt.getopt(sys.argv[1:], "ho:v", ["help"])
    except getopt.GetoptError, err:
        print str(err) # will print something like "option -a not recognized"
        usage()
        sys.exit(1)

    for o, a in opts:
        if o in ("-h", "--help"):
            usage()
            sys.exit()
        else:
            assert False, "unhandled option"

    if len(args) < 3:
        usage()
        sys.exit(2)

    generate(args[0],args[1],args[2])

if __name__ == "__main__":
    main(sys.argv)



# -*- coding: utf-8 -*-
#
# Copyright 2008 Simon Edwards <simon@simonzone.com>
# Copyright 2009 Petri Damstén <damu@iki.fi>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU Library General Public License as
# published by the Free Software Foundation; either version 2, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details
#
# You should have received a copy of the GNU Library General Public
# License along with this program; if not, write to the
# Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
from PyQt4.QtCore import *
from PyQt4.QtGui import *
from PyKDE4.plasma import Plasma
import plasma_importer
import os.path

class PythonRunnerScript(Plasma.RunnerScript):
    importer = None

    def __init__(self, parent):
        Plasma.RunnerScript.__init__(self,parent)
        if PythonRunnerScript.importer is None:
            PythonRunnerScript.importer = plasma_importer.PlasmaImporter()
        self.initialized = False

    def init(self):
        self.moduleName = str(self.runner().package().metadata().pluginName())
        self.pluginName = 'runner_' + self.moduleName.replace('-','_')

        PythonRunnerScript.importer.register_top_level(self.pluginName, str(self.runner().package().path()))

        # import the code at the file name reported by mainScript()
        relpath = os.path.relpath(str(self.mainScript()),str(self.runner().package().path()))
        if relpath.startswith("contents/code/"):
            relpath = relpath[14:]
        if relpath.endswith(".py"):
            relpath = relpath[:-3]
        relpath = relpath.replace("/",".")
        self.module = __import__(self.pluginName+'.'+relpath)
        basename = os.path.basename(str(self.mainScript()))
        basename = os.path.splitext(basename)[0]
        self.pyrunner = self.module.__dict__[basename].CreateRunner(None)
        self.pyrunner.setRunner(self.runner())
        self.pyrunner.setRunnerScript(self)
        self.connect(self, SIGNAL('prepare()'), self, SLOT('prepare()'))
        self.connect(self, SIGNAL('teardown()'), self, SLOT('teardown()'))
        self.connect(self, SIGNAL('createRunOptions(QWidget*)'),
                     self, SLOT('createRunOptions(QWidget*)'))
        self.connect(self, SIGNAL('reloadConfiguration()'),
                     self, SLOT('reloadConfiguration()'))
        self.pyrunner.init()

        self.initialized = True
        return True

    def __dtor__(self):
        PythonRunnerScript.importer.unregister_top_level(self.pluginName)
        self.pyrunner = None

    def match(self, search):
        self.pyrunner.match(search)

    def run(self, search, action):
        self.pyrunner.run(search, action)

    @pyqtSignature("prepare()")
    def prepare(self):
        self.pyrunner.prepare()

    @pyqtSignature("teardown()")
    def teardown(self):
        self.pyrunner.teardown()

    @pyqtSignature("createRunOptions(QWidget*)")
    def createRunOptions(self, widget):
        self.pyrunner.createRunOptions(widget)

    @pyqtSignature("reloadConfiguration()")
    def reloadConfiguration(self):
        self.pyrunner.reloadConfiguration()

def CreatePlugin(widget_parent, parent, component_data):
    return PythonRunnerScript(parent)
